//= skip
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

"use strict";

const { utils: Cu } = Components;
const rootURI = __SCRIPT_URI_SPEC__.replace("bootstrap.js", "");
const COMMONJS_URI = "resource://gre/modules/commonjs";
const { require } = Cu.import(COMMONJS_URI + "/toolkit/require.js", {});
const { Bootstrap } = require(COMMONJS_URI + "/sdk/addon/bootstrap.js");

var bootstrap = new Bootstrap(rootURI);

function install(data, reason) {
  bootstrap.install(data, reason);
}

function uninstall(data, reason) {
  if (reason == ADDON_UNINSTALL) {
    var chromeObj = require("chrome");
    var Cc = chromeObj.Cc;
    var Ci = chromeObj.Ci;

    // delete new blur settings
    var dir = Cc["@mozilla.org/file/directory_service;1"].getService(Ci.nsIProperties).get("ProfD", Ci.nsIFile);
    dir.append('dntme');
    if (dir.exists()) {
      try{dir.remove(true);}catch(e){}
    }

    // remove 2.0 preferences
    var prefService = Cc["@mozilla.org/preferences-service;1"].getService(Ci.nsIPrefService);
    var prefBranch = prefService.getBranch("extensions.dntp.");
    prefBranch.deleteBranch("");

    // delete 2.0 setting files
    var profileRoot = Cc["@mozilla.org/file/directory_service;1"].getService(Ci.nsIProperties).get("ProfD", Ci.nsIFile);
    var files = profileRoot.directoryEntries;
    while (files.hasMoreElements()) {
      var file = files.getNext().QueryInterface(Ci.nsIFile);
      if (file.leafName.match(/dntp-(.+).json/)) {
        file.remove(true);
      }
    }

    console.log("*** Blur settings cleared");
  }

  bootstrap.uninstall(data, reason);
}

function startup(data, reason) {
  bootstrap.startup(data, reason);
}

function shutdown(data, reason) {
  bootstrap.shutdown(data, reason);
}

;
