/**
 * Blur Copyright (c) 2008-2015 by Abine, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information
 * of Abine, Inc. ("Confidential Information"), subject
 * to the Non-Disclosure Agreement and/or License Agreement you entered
 * into with Abine. You shall use such Confidential Information only
 * in accordance with the terms of said Agreement(s). Abine makes
 * no representations or warranties about the suitability of the
 * software. The software is provided with ABSOLUTELY NO WARRANTY
 * and Abine will NOT BE LIABLE for ANY DAMAGES resulting from
 * the use of the software.
 *
 * Contact license@getabine.com with any license-related questions.
 *
 * https://www.abine.com
 * @license
 *
 */

;

// pre-processing directives
if (typeof LOG_FINEST === 'undefined') LOG_FINEST = true;
if (typeof LOG_DEBUG  === 'undefined') LOG_DEBUG = true;
if (typeof LOG_INFO   === 'undefined') LOG_INFO = true;
if (typeof LOG_WARN   === 'undefined') LOG_WARN = true;
if (typeof LOG_ERROR  === 'undefined') LOG_ERROR = true;




var Cc, Ci, Cu, Cm, Cr, components, ABINE_DNTME;

if (typeof ABINE_DNTME == 'undefined') {
  var chromeObj = require("chrome");
  Cc = chromeObj.Cc;
  Ci = chromeObj.Ci;
  Cu = chromeObj.Cu;
  Cm = chromeObj.Cm;
  Cr = chromeObj.Cr;
  components = chromeObj.components;

  ABINE_DNTME = require("resource://donottrackplus-at-abine-dot-com/lib/requireJSM").ABINE_DNTME;
}
;
//= skip



/** @const */
 var ABINE_SCHEME = "blur";

/** @const */ var CLASS_NAME = "Blur Protocol";
/** @const */ var CLASS_ID = components.ID("{6f4ad8ae-e902-4b19-cd20-1875958ad1f1}");
/** @const */ var CONTRACT_ID = "@mozilla.org/network/protocol;1?name=" + ABINE_SCHEME;


const self = require('sdk/self');
var ROOT = self.data.url();

// cache services
var consoleService = Cc["@mozilla.org/consoleservice;1"].getService(Ci.nsIConsoleService);
Cu.import("resource://gre/modules/Services.jsm");

var AbineProtocol = {
	QueryInterface: function(iid) {
		if (!iid.equals(Ci.nsIProtocolHandler) &&
				!iid.equals(Ci.nsISupports))
			throw components.results.NS_ERROR_NO_INTERFACE;
		return this;
	},

	_abineRootPath: null,
	scheme: ABINE_SCHEME,
	defaultPort: -1,
	protocolFlags:   Ci.nsIProtocolHandler.URI_NORELATIVE
				   | Ci.nsIProtocolHandler.URI_NOAUTH
				   | Ci.nsIProtocolHandler.URI_LOADABLE_BY_ANYONE
                                   | Ci.nsIProtocolHandler.URI_IS_LOCAL_RESOURCE,

	allowPort: function(port, scheme) {
		return false;
	},

	newURI: function(spec, charset, baseURI) {
		var uri = null;
		try {
			var stdUrl = Cc["@mozilla.org/network/standard-url;1"].createInstance(Ci.nsIStandardURL);
			stdUrl.init(1, -1, spec, charset, baseURI);
		    uri = stdUrl.QueryInterface(Ci.nsIURI);
		} catch (e) {
			uri.spec = 'cancelRequest';
		}
		return uri;
	},

	newChannel: function(aURI) {
		var requestedFile = aURI.spec;
		if (requestedFile == "cancelRequest") {
			return null;
		}

		requestedFile = requestedFile.substring(requestedFile.indexOf("://") + 3, requestedFile.length);

		if (requestedFile.indexOf("#") >= 0) {
			requestedFile = requestedFile.substring(0, requestedFile.indexOf("#"));
		}
		if (requestedFile.indexOf("?") >= 0) {
			requestedFile = requestedFile.substring(0, requestedFile.indexOf("?"));
		}

		requestedFile = ROOT+requestedFile.replace(/\/$/, '').replace(/^panel.html\//, '');
		if (requestedFile.indexOf('lib/') != -1) {
			requestedFile = requestedFile.replace('/data/', '/');
		}

		var channel = Services.io.newChannel(requestedFile, aURI.originCharset, null);
		channel.originalURI = aURI;

		return channel;
	},

	dump: function(aMessage) {
		consoleService.logStringMessage("Abine-Protocol: "+(new Date())+"\n" + aMessage);
	},

	createInstance: function(outer, iid) {
		if (outer) {
			throw Cr.NS_ERROR_NO_AGGREGATION
		}
		return this
	}
};

function runAsync(callback) {
	var runnable = {run: callback};
	Services.tm.currentThread.dispatch(runnable, Ci.nsIEventTarget.DISPATCH_NORMAL);
}

function register(){
	try {
		var registrar = components.manager.QueryInterface(Ci.nsIComponentRegistrar);
		registrar.registerFactory(CLASS_ID, CLASS_NAME, CONTRACT_ID, AbineProtocol);
	} catch(e) {
		// retry
		runAsync(register);
		return;
	}

	var unload = require("sdk/system/unload");
	unload.when(function() {
		unregister();
	});
};

function unregister() {
	runAsync(function() {
		var registrar = components.manager.QueryInterface(Ci.nsIComponentRegistrar);
		registrar.unregisterFactory(CLASS_ID, AbineProtocol);
	});
};

var child = require("sdk/remote/child");
child.process.port.on("init-protocol", function() {
	register();
});
